/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "SQLResultSet.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomSQLResultSet.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomSQLResultSet.h"
#include "gdom/PrivateIntGdomSQLResultSet.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::SQLResultSet* obj)
{
    return WebCore::cacheDOMObject<WebCore::SQLResultSet, GDOMSQLResultSet>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMSQLResultSet::GDOMSQLResultSet(PassRefPtr<WebCore::SQLResultSet> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMSQLResultSet::~GDOMSQLResultSet()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "SQLResultSet.h"
#include <gdom/GdomSQLResultSet.h>
#include <gdom/PrivateGdomSQLResultSet.h>
#include <gdom/PrivateIntGdomSQLResultSet.h>
#include <gdom/GdomSQLResultSetprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomSQLResultSet, gdom_sql_result_set, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomSQLResultSetPrivate {
    class WebCore::SQLResultSet *item;
};

#define GDOM_SQL_RESULT_SET_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_SQL_RESULT_SET, GdomSQLResultSetPrivate))
*/
G_END_DECLS
WebCore::SQLResultSet *
gdom_sql_result_set_get_private(GdomSQLResultSet *request)
{
    GDOMSQLResultSet *res;
    res = static_cast<GDOMSQLResultSet*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::SQLResultSet*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ROWS,
    PROP_INSERT_ID,
    PROP_ROWS_AFFECTED,
};


static void gdom_sql_result_set_finalize(GObject* object)
{
    /*GdomSQLResultSet* request = GDOM_SQL_RESULT_SET(object);*/
    /*GdomSQLResultSetPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_sql_result_set_parent_class)->finalize(object);
}

static void gdom_sql_result_set__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomSQLResultSet *self = GDOM_SQL_RESULT_SET(object);
    WebCore::SQLResultSet * gself = (gdom_sql_result_set_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_sql_result_set__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomSQLResultSet *self = GDOM_SQL_RESULT_SET(object);
    WebCore::SQLResultSet * gself = (gdom_sql_result_set_get_private(self));
    switch (prop_id) {
    case PROP_ROWS:
    {
         PassRefPtr<WebCore::SQLResultSetRowList> ptr = gself->rows();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_INSERT_ID:
    {
         WebCore::ExceptionCode ec = 0;
         g_value_set_int (value, gself->insertId(ec));
         break;
    }
    case PROP_ROWS_AFFECTED:
    {
         g_value_set_int (value, gself->rowsAffected());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_sql_result_set_class_init(GdomSQLResultSetClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_sql_result_set_finalize;
    g_klass->set_property = gdom_sql_result_set__set_property_fn;
    g_klass->get_property = gdom_sql_result_set__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ROWS,
            g_param_spec_object ("rows", /* name */
                "sql_result_set_rows", /* short description */
                "read-only  GdomSQLResultSetRowList * SQLResultSet.rows", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_SQL_RESULT_SET_ROW_LIST, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_INSERT_ID,
            g_param_spec_int ("insert_id", /* name */
                "sql_result_set_insert_id", /* short description */
                "read-only  gint SQLResultSet.insert_id", /* longer - could do with some extra doc stuff here */
                 G_MININT,        /* min */
                G_MAXINT, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ROWS_AFFECTED,
            g_param_spec_int ("rows_affected", /* name */
                "sql_result_set_rows_affected", /* short description */
                "read-only  gint SQLResultSet.rows_affected", /* longer - could do with some extra doc stuff here */
                 G_MININT,        /* min */
                G_MAXINT, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomSQLResultSetPrivate));*/
}

static void gdom_sql_result_set_init(GdomSQLResultSet* request)
{
    /*GdomSQLResultSetPrivate* priv = GDOM_SQL_RESULT_SET_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

